[−][src]Module urbit_http_api::chat
Structs
| Chat | A struct that provides an interface for interacting with Urbit chats |
| Message | A struct that represents a message that is to be sent to an Urbit chat.
|
| Chat | A struct that provides an interface for interacting with Urbit chats |
| Message | A struct that represents a message that is to be sent to an Urbit chat.
|