[][src]Struct urbit_http_api::chat::Message

pub struct Message { /* fields omitted */ }

A struct that represents a message that is to be sent to an Urbit chat. Message provides methods to build a message in chunks, thereby allowing you to add content which needs to be parsed, for example links or code.

Implementations

impl Message[src]

Methods for creating/building a Message

pub fn new() -> Message[src]

Create a new empty Message

pub fn add_text(&self, text: &str) -> Message[src]

Appends text to the end of the current message.

pub fn add_url(&self, url: &str) -> Message[src]

Appends a url to the end of the current message.