[−][src]Struct urbit_http_api::graphstore::GraphStore
A struct which exposes Graph Store functionality
Fields
channel: &'a mut ChannelImplementations
impl<'a> GraphStore<'a>[src]
pub fn post(
&mut self,
resource_ship: &str,
resource_name: &str,
contents: Vec<JsonValue>
) -> Result<String>[src]
&mut self,
resource_ship: &str,
resource_name: &str,
contents: Vec<JsonValue>
) -> Result<String>
Issue a post to Graph Store.
On success returns the index of the newly added node.
pub fn post_custom_index(
&mut self,
resource_ship: &str,
resource_name: &str,
contents: Vec<JsonValue>,
index: &str
) -> Result<String>[src]
&mut self,
resource_ship: &str,
resource_name: &str,
contents: Vec<JsonValue>,
index: &str
) -> Result<String>
Issue a post to Graph Store using a custom index.
On success returns the index of the newly added node.
pub fn add_nodes(
&mut self,
resource_ship: &str,
resource_name: &str,
nodes_json: JsonValue
) -> Result<()>[src]
&mut self,
resource_ship: &str,
resource_name: &str,
nodes_json: JsonValue
) -> Result<()>
Add nodes to Graph Store
pub fn remove_nodes(
&mut self,
resource_ship: &str,
resource_name: &str,
indices: Vec<&str>
) -> Result<()>[src]
&mut self,
resource_ship: &str,
resource_name: &str,
indices: Vec<&str>
) -> Result<()>
Remove nodes from Graph Store using the provided list of indices